@@ -1,20 +1,32 @@
 import unittest
 import mock
+import shutil
 
+from cpm.infrastructure.yaml_parser import YamlParser
+from cpm.domain.constants import PROJECT_DESCRIPTOR_FILE
 from cpm.domain.project import project_composer
 from cpm.domain.project import project_descriptor_parser
 from cpm.domain.project.project_descriptor import ProjectDescriptor, TargetDescription, CompilationPlan, PackageDescription
 
 
 class TestProjectComposer(unittest.TestCase):
+    def setUp(self):
+        self.parser = YamlParser(pure=True)
+        shutil.rmtree(PROJECT_DESCRIPTOR_FILE, ignore_errors=True)
+
+    def tearDown(self):
+        shutil.rmtree(PROJECT_DESCRIPTOR_FILE, ignore_errors=True)
+
     def test_should_compose_project_from_project_description_without_packages(self):
-        yaml_load = {
+        self.write_descriptor({
             'name': 'HalfLife3',
             'version': '1.0',
             'description': 'I want to believe'
-        }
-        project_description = project_descriptor_parser.parse_yaml(yaml_load)
+        })
+
+        project_description = project_descriptor_parser.parse_from('.')
         project = project_composer.compose(project_description, 'default')
+
         assert project.name == 'HalfLife3'
         assert project.version == '1.0'
         assert project.description == 'I want to believe'
@@ -23,7 +35,7 @@ class TestProjectComposer(unittest.TestCase):
 
     @mock.patch('cpm.domain.project.project_composer.filesystem')
     def test_should_compose_project_from_project_description_with_one_build_package(self, filesystem):
-        yaml_load = {
+        self.write_descriptor({
             'name': 'HalfLife3',
             'build': {
                 'packages': {
@@ -36,11 +48,13 @@ class TestProjectComposer(unittest.TestCase):
                 'libraries': ['pthread'],
                 'includes': ['./include']
             }
-        }
+        })
         filesystem.find.side_effect = [['shaders/shader.cpp'], ['shaders/water.c'], []]
         filesystem.parent_directory.return_value = '.'
-        project_description = project_descriptor_parser.parse_yaml(yaml_load)
+
+        project_description = project_descriptor_parser.parse_from('.')
         project = project_composer.compose(project_description, 'default')
+
         assert len(project.target.packages) == 1
         assert project.target.packages[0].path == 'shaders'
         assert project.target.packages[0].sources == ['shaders/shader.cpp', 'shaders/water.c']
@@ -51,8 +65,8 @@ class TestProjectComposer(unittest.TestCase):
         assert project.target.include_directories == {'.', './include'}
 
     @mock.patch('cpm.domain.project.project_composer.filesystem')
-    def test_should_compose_project_for_non_described_target(self, filesystem):
-        yaml_load = {
+    def test_should_raise_an_error_when_target_is_not_described(self, filesystem):
+        self.write_descriptor({
             'name': 'HalfLife3',
             'build': {
                 'packages': {
@@ -60,28 +74,15 @@ class TestProjectComposer(unittest.TestCase):
                         'cflags': ['-DUSE_PORTAL_GUN']
                     }
                 },
-                'cflags': ['-Wall'],
-                'ldflags': ['-pg'],
-                'libraries': ['pthread'],
-                'includes': ['./include']
             }
-        }
-        filesystem.find.side_effect = [['shaders/shader.cpp'], ['shaders/water.c'], []]
-        filesystem.parent_directory.return_value = '.'
-        project_description = project_descriptor_parser.parse_yaml(yaml_load)
-        project = project_composer.compose(project_description, 'non-described-target')
-        assert len(project.target.packages) == 1
-        assert project.target.packages[0].path == 'shaders'
-        assert project.target.packages[0].sources == ['shaders/shader.cpp', 'shaders/water.c']
-        assert project.target.packages[0].cflags == ['-DUSE_PORTAL_GUN', '-Wall']
-        assert project.target.cflags == ['-Wall']
-        assert project.target.ldflags == ['-pg']
-        assert project.target.libraries == ['pthread']
-        assert project.target.include_directories == {'.', './include'}
+        })
+
+        project_description = project_descriptor_parser.parse_from('.')
+        self.assertRaises(project_composer.TargetNotDescribed, project_composer.compose, project_description, 'non-described-target')
 
     @mock.patch('cpm.domain.project.project_composer.filesystem')
     def test_should_compose_project_from_project_description_with_one_target_build_package(self, filesystem):
-        yaml_load = {
+        self.write_descriptor({
             'name': 'HalfLife3',
             'targets': {
                 'default': {
@@ -93,7 +94,8 @@ class TestProjectComposer(unittest.TestCase):
                         },
                         'cflags': ['-Wall'],
                         'ldflags': ['-pg'],
-                        'libraries': ['pthread']
+                        'libraries': ['pthread'],
+                        'includes': ['./include']
                     },
                     'post_build': ['./post_build.sh'],
                     'main': 'main.c',
@@ -103,11 +105,13 @@ class TestProjectComposer(unittest.TestCase):
                     'toolchain_prefix': 'arm-linux-gnueabi-'
                 }
             }
-        }
+        })
         filesystem.find.side_effect = [['shaders/shader.cpp'], ['shaders/water.c'], []]
         filesystem.parent_directory.return_value = '.'
-        project_description = project_descriptor_parser.parse_yaml(yaml_load)
+
+        project_description = project_descriptor_parser.parse_from('.')
         project = project_composer.compose(project_description, 'default')
+
         assert len(project.target.packages) == 1
         assert project.target.packages[0].path == 'shaders'
         assert project.target.packages[0].sources == ['shaders/shader.cpp', 'shaders/water.c']
@@ -115,7 +119,7 @@ class TestProjectComposer(unittest.TestCase):
         assert project.target.cflags == ['-Wall']
         assert project.target.ldflags == ['-pg']
         assert project.target.libraries == ['pthread']
-        assert project.target.include_directories == {'.'}
+        assert project.target.include_directories == {'.', './include'}
         assert project.target.post_build == ['./post_build.sh']
         assert project.target.main == 'main.c'
         assert project.target.image == 'cpmbits/docker'
@@ -125,7 +129,7 @@ class TestProjectComposer(unittest.TestCase):
 
     @mock.patch('cpm.domain.project.project_composer.filesystem')
     def test_should_compose_project_from_project_description_with_one_target_test_package(self, filesystem):
-        yaml_load = {
+        self.write_descriptor({
             'name': 'HalfLife3',
             'test': {
                 'includes': ['./test/include']
@@ -144,11 +148,13 @@ class TestProjectComposer(unittest.TestCase):
                     },
                 }
             }
-        }
+        })
         filesystem.find.side_effect = [['shaders/shader.cpp'], ['shaders/water.c'], []]
         filesystem.parent_directory.return_value = '.'
-        project_description = project_descriptor_parser.parse_yaml(yaml_load)
+
+        project_description = project_descriptor_parser.parse_from('.')
         project = project_composer.compose(project_description, 'default')
+
         assert len(project.test.packages) == 1
         assert project.test.packages[0].path == 'shaders'
         assert project.test.packages[0].sources == ['shaders/shader.cpp', 'shaders/water.c']
@@ -160,20 +166,22 @@ class TestProjectComposer(unittest.TestCase):
 
     @mock.patch('cpm.domain.project.project_composer.filesystem')
     def test_should_compose_project_from_project_description_with_one_test(self, filesystem):
-        yaml_load = {
+        self.write_descriptor({
             'name': 'HalfLife3',
-        }
+        })
         filesystem.find.side_effect = [['tests/test_one.cpp']]
         filesystem.parent_directory.return_value = '.'
-        project_description = project_descriptor_parser.parse_yaml(yaml_load)
+
+        project_description = project_descriptor_parser.parse_from('.')
         project = project_composer.compose(project_description, 'default')
+
         assert len(project.test.test_suites) == 1
         assert project.test.test_suites[0].name == 'test_one'
         assert project.test.test_suites[0].main == 'tests/test_one.cpp'
 
     @mock.patch('cpm.domain.project.project_composer.filesystem')
     def test_compose_from_description_with_customized_bit_compilation(self, filesystem):
-        yaml_load = {
+        self.write_descriptor({
             'name': 'HalfLife3',
             'build': {
                 'bits': {
@@ -184,12 +192,14 @@ class TestProjectComposer(unittest.TestCase):
                     }
                 }
             }
-        }
+        })
         filesystem.find.side_effect = [['tests/test_one.cpp'], ['nano33/nano33.cpp'], []]
         filesystem.parent_directory.return_value = '.'
-        project_description = project_descriptor_parser.parse_yaml(yaml_load)
+
+        project_description = project_descriptor_parser.parse_from('.')
         arduino_bit = ProjectDescriptor(
             name='arduino',
+            version='1.0.0',
             targets={
                 'nano33': TargetDescription(
                     name='nano33',
@@ -203,5 +213,10 @@ class TestProjectComposer(unittest.TestCase):
         )
         project_description.build.bits['arduino'] = arduino_bit
         project = project_composer.compose(project_description, 'default')
-        assert project.target.bits[0].packages[0].path == 'bits/arduino/nano33'
+
+        assert project.target.bits[0].packages[0].path == 'bits/arduino/1.0.0/nano33'
         assert project.target.bits[0].packages[0].cflags == ['-mcpu=atmel', '-DBIT_FLAG']
+
+    def write_descriptor(self, data):
+        with open(PROJECT_DESCRIPTOR_FILE, 'w') as stream:
+            self.parser.dump(data, stream)
