@@ -1,7 +1,8 @@
 import unittest
 from unittest import mock
+from pathlib import Path
 
-from ruamel.yaml import YAML
+from cpm.infrastructure.yaml_parser import YamlParser
 
 from cpm.domain.constants import PROJECT_DESCRIPTOR_FILE
 from cpm.domain.project import project_descriptor_parser
@@ -11,30 +12,29 @@ from cpm.domain.project import project_descriptor_editor
 class TestProjectDescriptorEditor(unittest.TestCase):
     @mock.patch('cpm.domain.project.project_descriptor_editor.filesystem')
     def test_parse_project_descriptor_with_just_the_project_information(self, filesystem):
-        yaml_payload = '''name: 'bender bender rodriguez'
+        yaml = YamlParser()
+        with open(PROJECT_DESCRIPTOR_FILE, 'w') as stream:
+            stream.write(f'''name: 'bender bender rodriguez'
 version: '1.0'
 description: 'kill all humans'
 build:
     packages:
     bits:
-    cflags:
 test:
 targets:
-'''
-        yaml = YAML()
-        yaml_document = yaml.load(yaml_payload)
-        project_descriptor = project_descriptor_parser.parse_yaml(yaml_document)
+''')
+        yaml_document = yaml.load_from(Path(PROJECT_DESCRIPTOR_FILE))
+        project_descriptor = project_descriptor_parser.digest_yaml(yaml_document)
         project_descriptor.yaml_document = yaml_document
 
         project_descriptor_editor.update('.', project_descriptor, {'name': 'pepito', 'version': '1.0.0'})
 
-        filesystem.write_file.assert_called_with(f'./{PROJECT_DESCRIPTOR_FILE}', '''name: pepito
+        filesystem.write_file.assert_called_with(f'./{PROJECT_DESCRIPTOR_FILE}', f'''name: pepito
 version: 1.0.0
 description: kill all humans
 build:
   packages:
   bits:
-  cflags:
 test:
 targets:
 ''')
