@@ -2,9 +2,11 @@ import unittest
 import mock
 import os
 import shutil
-import yaml
+import zipfile
 
+from cpm.domain.constants import PROJECT_DESCRIPTOR_FILE
 from cpm.infrastructure import filesystem
+from cpm.infrastructure import yaml_parser
 from cpm.api import create
 from cpm.api import install
 from cpm.api import build
@@ -151,7 +153,7 @@ class TestCpm(unittest.TestCase):
     def test_after_recursive_bit_installation(self):
         os.chdir(self.PROJECT_DIRECTORY)
         self.add_bit('test', 'cest', '1.0')
-        self.set_test_cflags(['-std=c++11'])
+        self.set_test_cppflags(['-std=c++11'])
         self.add_test('test_case.cpp')
         install.execute(['-s', 'http://localhost:8000'])
         result = test.execute([])
@@ -160,7 +162,7 @@ class TestCpm(unittest.TestCase):
     def test_specifying_test_file(self):
         os.chdir(self.PROJECT_DIRECTORY)
         self.add_bit('test', 'cest', '1.0')
-        self.set_test_cflags(['-std=c++11'])
+        self.set_test_cppflags(['-std=c++11'])
         self.add_test('test_case1.cpp')
         self.add_test('test_case2.cpp')
         install.execute(['-s', 'http://localhost:8000'])
@@ -170,13 +172,35 @@ class TestCpm(unittest.TestCase):
     def test_specifying_test_directory(self):
         os.chdir(self.PROJECT_DIRECTORY)
         self.add_bit('test', 'cest', '1.0')
-        self.set_test_cflags(['-std=c++11'])
+        self.set_test_cppflags(['-std=c++11'])
         self.add_test('test_case1.cpp')
         self.add_test('test_case2.cpp')
         install.execute(['-s', 'http://localhost:8000'])
         result = test.execute(['tests'])
         assert result.status_code == 0
 
+    def test_using_reference_to_external_file_in_cflags(self):
+        os.chdir(self.PROJECT_DIRECTORY)
+        project_yaml = '''build:
+  bits:
+  packages:
+name: test_project
+targets:
+  default:
+    main: main.cpp
+test:
+  bits:
+    cest: '1.0'
+  cflags: !include test_cflags.yaml
+version: 0.0.1
+'''
+        with open('project.yaml', 'w') as stream:
+            stream.write(project_yaml)
+        yaml_parser.dump(['-std=c++11'], 'test_cflags.yaml')
+        install.execute(['-s', 'http://localhost:8000'])
+        result = test.execute(['tests'])
+        assert result.status_code == 0
+
     def test_failing_test_after_recursive_bit_installation(self):
         os.chdir(self.PROJECT_DIRECTORY)
         self.add_bit('test', 'cest', '1.0')
@@ -223,16 +247,42 @@ class TestCpm(unittest.TestCase):
         result = create.execute(['-s', 'http://localhost:8000', '-t', f'{self.PROJECT_NAME}:0.0.1', self.PROJECT_NAME_FROM_TEMPLATE])
         assert result == Result(0, f'Created project {self.PROJECT_NAME_FROM_TEMPLATE}')
 
+    def test_packaging_including_external_files(self):
+        from cpm.domain.project_packager import ProjectPackager
+        from cpm.domain.project import project_descriptor_parser
+        os.chdir(self.PROJECT_DIRECTORY)
+        project_yaml = '''build:
+  bits:
+  packages:
+    empty_package:
+name: test_project
+targets:
+  default:
+    main: main.cpp
+test:
+  bits:
+    cest: '1.0'
+  cflags: !include test_cflags.yaml
+version: 0.0.1
+'''
+        with open('project.yaml', 'w') as stream:
+            stream.write(project_yaml)
+        yaml_parser.dump(['-std=c++11'], 'test_cflags.yaml')
+        os.mkdir('empty_package')
+        project_descriptor = project_descriptor_parser.parse_from('.')
+        pack = ProjectPackager().pack(project_descriptor, 'dist')
+        zip = zipfile.ZipFile(pack)
+        files_in_zip = zip.namelist()
+        assert 'test_cflags.yaml' in files_in_zip
+
     def add_bit(self, plan, name, version):
-        with open(f'project.yaml') as stream:
-            project_descriptor = yaml.safe_load(stream)
+        project_descriptor = yaml_parser.load(PROJECT_DESCRIPTOR_FILE)
         if plan not in project_descriptor or not project_descriptor[plan]:
             project_descriptor[plan] = {}
         project_descriptor[plan]['bits'] = {
             name: version
         }
-        with open(f'project.yaml', 'w') as stream:
-            yaml.dump(project_descriptor, stream)
+        yaml_parser.dump(project_descriptor, PROJECT_DESCRIPTOR_FILE)
 
     def add_test(self, file_name, fails=False):
         if not filesystem.directory_exists('tests'):
@@ -309,17 +359,20 @@ class TestCpm(unittest.TestCase):
             lambda descriptor: descriptor['test'].update({'cflags': cflags})
         )
 
+    def set_test_cppflags(self, cppflags):
+        self.modify_descriptor(
+            lambda descriptor: descriptor['test'].update({'cppflags': cppflags})
+        )
+
     def set_test_ldflags(self, ldflags):
         self.modify_descriptor(
             lambda descriptor: descriptor['test'].update({'ldflags': ldflags})
         )
 
     def modify_descriptor(self, modify):
-        with open(f'project.yaml') as stream:
-            project_descriptor = yaml.safe_load(stream)
+        project_descriptor = yaml_parser.load(PROJECT_DESCRIPTOR_FILE)
         modify(project_descriptor)
-        with open(f'project.yaml', 'w') as stream:
-            yaml.dump(project_descriptor, stream)
+        yaml_parser.dump(project_descriptor, PROJECT_DESCRIPTOR_FILE)
 
     def add_main_with_user_include(self):
         filesystem.create_file(
